@@ -1,4 +1,4 @@
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 ## Import packages
 import numpy as np
@@ -70,8 +70,8 @@ def find_vm_sd(channel_responses,plotting=False):
         plt.plot(make_gaussian_iter(180,np.arange(10,180)[np.argmin(losses)]))
         
     return np.arange(10,180)[np.argmin(losses)]
-def rotate_recon(trial_features,recons):
-    aligned_crs = np.array([np.roll(recons[t,:],-trial_features[t]) for t in range(len(trial_features))])
+def rotate_recon(features,recons):
+    aligned_crs = np.array([np.roll(recons[t,:],-features[t]) for t in range(len(features))])
     return aligned_crs
 
 ## Main functions
@@ -118,8 +118,6 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
     >>> from inverted_encoding import IEM
     >>> predictions, confidences, recons = IEM(trialbyvoxel,features,stim_max=180,is_circular=True)
     """
-
-    np.random.seed(1) # make procedure reproducible by setting rng
     ntrials = len(features)
     
     # ensure stimulus features are integers less than stim_max
@@ -204,7 +202,7 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
         confidences[test_index] = precisions
         recons[test_index,:] = cr_tsts
     # align the reconstructions at zero, such that ideally reconstruction is centered at 0 when plotted
-    aligned_recons = rotate_recon(trial_features,recons)
+    aligned_recons = rotate_recon(features,recons)
 
     return predictions, confidences, recons, aligned_recons
 
@@ -233,7 +231,6 @@ def permutation(features,stim_max=180,num_perm=5000,is_circular=True):
     >>> from inverted_encoding import permutation
     >>> null_mae_distribution = permutation(features,stim_max=180,is_circular=True)
     """
-    np.random.seed(1) # make procedure reproducible by setting rng
     ntrials = len(features)
     
     # ensure stimulus features are integers less than stim_max
